
# title: "Refinement of 16S rRNA analysis for low-biomass biospecimens."
# Authors: "Remy VILLETTE, Gaelle AUTAA, Sophie HIND, Johanna B HOLM, Alicia MORENO-SABATER, Martin LARSEN"
# date: "May 2021"
##------------------
# Install dependencies (don't run unless needed, takes some time)
if (!requireNamespace("BiocManager", quietly = TRUE))
  install.packages("BiocManager")
BiocManager::install(version = "3.10")
BiocManager::install(c("phyloseq"))
BiocManager::install(c("phyloseq",'ggsci',"ggpubr","ade4","tidyr","ggrepel"
                       ,"vegan","magrittr","RColorBrewer","ComplexHeatmap"
                       ,"corrplot","Hmisc","readxl","dendextend","ranacapa"))
BiocManager::install(c("ranacapa"))
if (!requireNamespace("BiocManager", quietly = TRUE))
  install.packages("BiocManager")

BiocManager::install("multtest")
BiocManager::install("phyloseq")

if (!requireNamespace("devtools", quietly = TRUE))
  install.packages('devtools')
library(devtools)
devtools::install_github("gauravsk/ranacapa")

source('http://bioconductor.org/biocLite.R')
biocLite('phyloseq')
##------------------

library(phyloseq)
library(vegan)
library(ggplot2)
library(ggsci)
library(ggpubr)
library(ade4)
library(tidyverse)
library(ggrepel)
library(vegan)
library(magrittr)
library(RColorBrewer)
library(ComplexHeatmap)
library(corrplot)
library(Hmisc)
library(readxl)
library(ranacapa)



# choose your working directory
setwd(dirname(file.choose()))
ps<- readRDS("16S_Scarcity_Villette_et_al_ps.rds" )

taxa= as.data.frame(tax_table(ps))
taxa$ASV<- as.vector(paste0("ASV_", c(1:length(taxa$Species))))#create a vector that match the length of taxa_table


# load metadata file: "2021-05 Metadata_16s_Scarcity_Villette.xlsx"

metadata= read_xlsx(file.choose())%>% as.data.frame() %>% set_rownames(metadata$Filename)

# check the rarefaction curve 
p= ranacapa::ggrare(Donor.count, label = "Concentration", color = "SampleName", parallel = T)+facet_grid(~PCR)

ps<- phyloseq(otu_table(otu_table(ps), taxa_are_rows = F), tax_table(as.matrix(taxa)),
                   sample_data(metadata)) #add the new tax_table with the ASV column
apply(otu_table(ps), 1, sum)%>% sort()%>% barplot()

# we want to rarefy to 10 000 reads to respect the hypothetical coverage of 10^4 cells aka 10 000
# However we don't want to exclude samples that doesn't reach 10 000 reads, so we will only rarefy the samples with at least 10 000 reads. Please read argumentation in manuscript.

apply(otu_table(ps)[which(sample_data(ps)$Platform=="GenoToul")], 1, sum)%>% sort()%>% barplot()%>%abline(1,10000, col= "red")

human = subset_samples(ps, Platform=="GenoToul")
# Rarefy all the samples with more than 10 000 reads
high = subset_samples(human, sample_names(human) %in% sample_names(human)[which(apply(otu_table(human), 1, sum) > 10000)])%>% 
  rarefy_even_depth(. ,sample.size = 10000, verbose = T, rngseed = T)
# But not those with less than 10 000 reads
low = subset_samples(human, !sample_names(human) %in% sample_names(human)[which(apply(otu_table(human), 1, sum) > 10000)])


# In case you want to perform the analysis with rarefaction at the minimum depth or no rarefaction run one of the following instead
Donor <- human # for no rarefaction
Donor <- rarefy_even_depth(human, samplesize= 1686, verbose = T, rngseed = T) # for a rarefaction at the minimum read depth

  
Donor<- merge_phyloseq(high, low) 
apply(otu_table(Donor), 1, sum)%>% barplot()%>%abline(coef = c(10000,0),  col= "red", lwd=2)
Donor= Donor %>% transform_sample_counts(function(x)x/sum(x))
sample_names(Donor)= paste(Donor@sam_data$SampleName, 
                           Donor@sam_data$Mechanical_Lyse, Donor@sam_data$PCR, 
                           Donor@sam_data$Concentration,sep="_")
 

MCS= subset_samples(ps, Platform=="BioFidal")

    apply(otu_table(MCS), 1, sum)%>%  barplot()

#### DONOR
"Serial dilution analysis"

# alpha diversity
Donor.rich = as.data.frame(estimate_richness(Donor, measures = "Shannon")) # estimate richness
Donor.rich$SampleName<- Donor@sam_data$SampleName #paste sample info 
Donor.rich$PCR= Donor@sam_data$PCR
Donor.rich$Concentration = Donor@sam_data$Concentration

svg("shannon_donor.svg", height = 10, width = 15)

ggplot(Donor.rich, aes(x=PCR, y=Shannon, fill=Concentration))+
  facet_grid(~SampleName, scales = "free_x", space = "free")+geom_bar(stat='identity', position = "dodge")+
  scale_fill_futurama("planetexpress", name= "Microbes quantity", labels= c("10⁴","10⁵", "10⁶", "10⁷", "10⁸"))+theme_bw()+ylab("Shannon index")+
  theme(strip.text = element_text(size = 40, face = "bold"), strip.background = element_blank(), 
        legend.position = "bottom", 
        legend.text = element_text(size = 25, face="bold"), axis.title.x = element_blank(), 
        axis.text.x = element_text(size = 30, face = "bold"),
        legend.title = element_text(size = 25, face="bold"), axis.title.y=element_text(size = 30, 
                                                                                       face="bold"), axis.text.y = element_text(size = 20), panel.grid = element_blank())

dev.off()

"is the alpha diversity different between the two PCR protocols ? "
x= Donor.rich[Donor.rich$Concentration!="10^4",]
t.test(x$Shannon~x$PCR, paired=T)
ggplot(x, aes(PCR, Shannon))+geom_boxplot()+stat_compare_means(method = "t.test",paired = T, label.y = 2.5)+coord_flip()
 "almost !"

#Phylum composititon

# Dilution only for the Donors

Donor<- prune_taxa(taxa_sums(Donor)>0, Donor) #remove taxa that are not present anymore
Phylum.donor<- tax_glom(Donor, "Phylum") # aggregate taxa to the phylum level
Class.donor<- tax_glom(Donor, "Class") # aggregate taxa to the class level

#Graphical representation
svg("phylum_composition_donor_bis.svg", width = 15, height = 10)
plot_bar(Phylum.donor, x = "Concentration", fill = "Phylum")+facet_grid(SampleName~PCR, space = "free", scales = "free")+
  scale_fill_futurama("planetexpress")+geom_bar(stat = "identity", position = 'fill')+labs(x="Microbes quantity", y="Relative abundance")+
  scale_x_discrete( labels= c("10^4"="10⁴","10^5"="10⁵","10^6"="10⁶","10^7"="10⁷","10^8"="10⁸"))+
  theme_bw()+theme(strip.background = element_blank(), axis.title.x = element_text(size=30, face="bold"), 
                   strip.text = element_text(size = 40, face = "bold"), axis.text.x = element_text(size = 25, face = "bold"), 
                   axis.text.y = element_text(size = 20), axis.title.y = element_text(size = 30, face="bold"), legend.title = element_blank(), 
                   legend.text = element_text(size = 20, face="bold.italic"), legend.spacing.x = unit(0.5,"cm"), 
                   panel.grid = element_blank())
dev.off()

#class level
tol21rainbow= c("#771155", "#AA4488", "#CC99BB", "#114477", "#4477AA", "#77AADD", "#117777", "#44AAAA", "#77CCCC", "#117744", "#44AA77", "#88CCAA", "#777711", "#AAAA44", "#DDDD77", "#774411", "#AA7744", "#DDAA77", "#771122", "#AA4455", "#DD7788")

svg("class_composition_donor_bis.svg", width = 15, height = 10)
plot_bar(Class.donor, x = "Concentration", fill = "Class")+facet_grid(SampleName~PCR, scales = "free", space = "free")+labs(x="Microbes quantity", y="Relative abundance")+
  scale_fill_manual(values = tol21rainbow)+geom_bar(stat = "identity", position = 'fill')+scale_x_discrete(labels= c("10^4"="10⁴","10^5"="10⁵","10^6"="10⁶","10^7"="10⁷","10^8"="10⁸"))+
  theme_bw()+theme(strip.background = element_blank(),axis.title.x = element_text(size=30, face="bold"), 
                   strip.text = element_text(size = 40, face = "bold"), axis.text.x = element_text(size = 25, face = "bold"), 
                   axis.text.y = element_text(size = 20), axis.title.y = element_text(size = 30, face="bold"), legend.title = element_blank(), 
                   legend.text = element_text(size = 20, face="bold.italic"), legend.spacing.x = unit(0.5,"cm"), 
                   panel.grid = element_blank())

dev.off()

# Analyse the distance between samples

ord.donor <- ordinate(Donor, method = "PCoA", distance = "bray") # Ordinate by PCoA

#get distance for later
dist.donor <- distance(Donor, method = "bray")  
# dist.donor <- vegdist(otu_table(Donor), method = "bray")  # In case you encounter problems with the first function, you can use this line


svg("PCoA_dilution.svg", width = 13, height = 10)
plot_ordination(Donor, ord.donor, color = "PCR", shape="SampleName")+geom_point(size=7)+ geom_label_repel(aes(label= Concentration), size=7)+
  
  scale_color_futurama("planetexpress")+theme_bw()+
  theme(legend.title = element_blank(), legend.text = element_text(size = 20, face = "bold"),
        axis.ticks = element_blank(), axis.text = element_blank(), axis.title = element_text(size = 25, face = "bold"), legend.position = "bottom", 
        legend.spacing.x = unit(0.3, "cm"))

dev.off()

adonis(dist.donor~SampleName, data = data.frame(sample_data(Donor)), permutations = 10000) #get permanova result for the PCoA, change between PCR or Sample
adonis(dist.donor~PCR, data = data.frame(sample_data(Donor)), permutations = 10000) #get permanova result for the PCoA, change between PCR or Sample

"adonis return a signif for Donor origin but not for PCR"
"let see how PCR perform when we compare each sample distance to the higher concentration"

dist_higher= as.matrix(dist.donor) #get the distance matrix
dist_higher<- as.data.frame(dist_higher[,c(3, 4,9,10)]) #select the columns belonging to the higher concentrations aka 10^8

dist_higher= rownames_to_column(dist_higher) #get rownames as a column
dist_higher =separate(dist_higher, col = "rowname", 
                             into = c("Donor","Lysing_time","PCR","Concentration"), sep = "_") #separate names

# Subset dataset
# First Nested PCR
dist_Nested= dist_higher[,c(-5,-8)]
dist_Nested_HD1= subset(dist_Nested, PCR=='Nested'& Donor=="HD1")%>% extract(-6) %>% set_colnames(c("Donor","Lysing_time","PCR","Concentration", "Distance"))
dist_Nested_HD2= subset(dist_Nested, PCR=='Nested'& Donor=="HD2") %>% extract(-5)%>% set_colnames(c("Donor","Lysing_time","PCR","Concentration", "Distance"))

# Then Standard PCR
dist_standard= dist_higher[,c(-6,-7)]
dist_standard_HD1= subset(dist_standard, PCR=='Standard'& Donor=="HD1")%>% extract(-6)%>% set_colnames(c("Donor","Lysing_time","PCR","Concentration", "Distance"))
dist_standard_HD2= subset(dist_standard, PCR=='Standard'& Donor=="HD2")%>% extract(-5) %>% set_colnames(c("Donor","Lysing_time","PCR","Concentration", "Distance"))

  
dist_higher<- rbind(dist_Nested_HD1, dist_Nested_HD2, dist_standard_HD2, dist_standard_HD1 )#bind all datasets

dist_higher$DonorPCR= paste(dist_higher$Donor, dist_higher$PCR, "_")#remake the names to plot nicely
dist_higher$Distance= as.numeric(dist_higher$Distance)

# Here we plot the distance of samples from the higher concentration sample
ggplot(dist_higher, aes(x=Concentration, y=as.numeric(Distance), color=PCR, shape=Donor))+geom_point()+
  geom_line(mapping = aes(x=Concentration, y= Distance, color=PCR, group=DonorPCR ))+scale_x_discrete(labels= c("10⁴", "10⁵", "10⁶","10⁷", "10⁸"))+
  ylab("Bray-curtis distance from higher concentration")+
  theme_classic()+theme(axis.title.x = element_blank(), axis.text = element_text(size = 15), 
                        axis.title.y = element_text(size = 20))

#Heatmap
"We perform an analysis with the top30 genus to determine why some samples are that dinstant from the higher concentration"
Heatmap.donor<- tax_glom(Donor, "Genus") #gagregate at genus level
Heatmap.donor<- prune_taxa(names(sort(taxa_sums(Heatmap.donor),TRUE)[1:30]), Heatmap.donor) #select top 30

x= t(as.matrix(Heatmap.donor@otu_table@.Data)) # Change the direction of the data frame, we want to have taxa as rows and samples as columns

dend= hclust(distance(Donor, method="bray"), "ward.D2") # Get the distance
dend= hclust(vegdist(Donor@otu_table, method="bray"), "ward.D2") # Same as before
"In order to chose the number of clusters in our data, we use the Clusgap function, here a wrapper from phyloseq package."
plot(gapstat_ord(ordinate(Donor, method = "PCoA", distance="bray"),K.max=10))
"The plot gives 9 as the best number of clusters, however, graphically 3 is the best, you can try to use more than 3 when using this script"

dend= dendextend:: click_rotate(as.dendrogram(dend)) # rotate the branches by clicking on the branches you want to rotate
scales::show_col(tol21rainbow) #show palette and select nice colors

group= HeatmapAnnotation(Donor=Heatmap.donor@sam_data$SampleName,PCR=Heatmap.donor@sam_data$PCR , 
                         col=list(Donor= c("HD1"="#114477", "HD2"="#AA4488"),
                         PCR= c("Nested"="#44AAAA" , "Standard"="#DDDD77")), show_annotation_name = T, 
                         annotation_name_gp =  gpar(fontsize=15, fontface="bold")) #make annotation for the PCR group and the Donor group 
name= HeatmapAnnotation(Concentration= anno_text(Heatmap.donor@sam_data$Concentration, gp = gpar(fontsize=14, fontface="bold"))) #once more

#Graphical representation
svg("heatmap_top30.svg", width = 15, height = 10)
Heatmap(as.matrix(scale(x)), top_annotation = group, bottom_annotation = name,
        cluster_rows = F, cluster_columns = as.dendrogram(dend), #take the full phyloseq object to get the real distance matrix 
        row_labels = Heatmap.donor@tax_table[,"Genus"],
        row_names_gp = gpar(fontsize=15, fontface="bold.italic"),show_column_names = F, 
        col = c("white","#88CCAA","#771122"), column_dend_height = unit(3, "cm"), name = "Abundance", 
        column_split = 3, column_gap = unit(5, "mm"), column_title = NULL) # change column_split to the number of gaps you want, 3 is the best to explain the data
dev.off()


# We evaluate how samples correlate with each other
corHD= prune_taxa(taxa_sums(Donor)>0, Donor)%>%
  tax_glom(., "Genus")%>% psmelt(.)%>%.[,c("Abundance","SampleName","PCR","Concentration","Genus")]%>% 
      spread(., key=Genus, value=Abundance) #aggregate to genus, melt the S4 object to a classis dataframe, spread it and select the desired columns

#transform the dataset to have correlation between samples and not between genus
# Make unique names and remove the first columns (only numeric values are authorized for the following script)
corHD1_nested= subset(corHD, SampleName=="HD1" & PCR=="Nested") %>% set_rownames(with(.,paste(PCR, Concentration)))%>% select(c(-1,-2,-3)) %>% t
corHD1_standard =subset(corHD, SampleName=="HD1"&PCR=="Standard") %>% set_rownames(with(., paste(PCR, Concentration)))%>% select(c(-1,-2,-3)) %>% t
corHD2_nested= subset(corHD, SampleName=="HD2"&PCR=="Nested") %>% set_rownames(with(.,paste(PCR, Concentration)))%>% select(c(-1,-2,-3)) %>% t
corHD2_standard= subset(corHD, SampleName=="HD2"&PCR=="Standard") %>% set_rownames(with(.,paste(PCR, Concentration)))%>% select(c(-1,-2,-3)) %>% t

x= list(corHD1_nested, corHD1_standard, corHD2_nested, corHD2_standard) # Make a list of matrix 
names(x)= c("HD1 Nested","HD1 Standard","HD2 Nested","HD2 Standard")
M <- lapply(x, function(x) rcorr(as.matrix(x), type = "spearman")) # Apply the rcorr function to the list of matrix
svg("cor_HD.svg", width = 15, height = 15)
par(mfrow=c(2,2))
# Apply the corrplot (graphical function) to the list of correlation matrix "M"
lapply(M, function(x){
  corrplot(x$r, type="lower", tl.cex=1,tl.srt=30,tl.pos='ld', tl.col = "black",
           p.mat = x$P, insig = "blank", sig.level = 0.001, method="pie", diag = F, 
           cl.lim = c(0,1), addgrid.col = F, addCoef.col = T, cl.cex = 1.2 )
})
dev.off()

#rarefaction curve 
"rarefaction curve takes time to plot"
Donor.count= subset_samples(ps, SampleOrigin=="HD1" | SampleOrigin=="HD2") #select only donor in phyloseq object
sample_names(Donor.count)= paste(Donor.count@sam_data$SampleName, 
                            Donor.count@sam_data$PCR, 
                           Donor.count@sam_data$Concentration,sep="_")

# The function below is a modified code from ranacapa package, this allow to control the size of the text for graphical purpose
# All the credit goes to the author of this package, this is just an adjustment 
ggrare_2= function (physeq_object, step = 10, label = NULL, color = NULL, 
                    plot = TRUE, parallel = FALSE, se = TRUE, size=6) 
{
  x <- methods::as(phyloseq::otu_table(physeq_object), "matrix")
  if (phyloseq::taxa_are_rows(physeq_object)) {
    x <- t(x)
  }
  tot <- rowSums(x)
  S <- rowSums(x > 0)
  nr <- nrow(x)
  rarefun <- function(i) {
    cat(paste("rarefying sample", rownames(x)[i]), sep = "\n")
    n <- seq(1, tot[i], by = step)
    if (n[length(n)] != tot[i]) {
      n <- c(n, tot[i])
    }
    y <- vegan::rarefy(x[i, , drop = FALSE], n, se = se)
    if (nrow(y) != 1) {
      rownames(y) <- c(".S", ".se")
      return(data.frame(t(y), Size = n, Sample = rownames(x)[i]))
    }
    else {
      return(data.frame(.S = y[1, ], Size = n, Sample = rownames(x)[i]))
    }
  }
  if (parallel) {
    out <- parallel::mclapply(seq_len(nr), rarefun, mc.preschedule = FALSE)
  }
  else {
    out <- lapply(seq_len(nr), rarefun)
  }
  df <- do.call(rbind, out)
  if (!is.null(phyloseq::sample_data(physeq_object, FALSE))) {
    sdf <- methods::as(phyloseq::sample_data(physeq_object), 
                       "data.frame")
    sdf$Sample <- rownames(sdf)
    data <- merge(df, sdf, by = "Sample")
    labels <- data.frame(x = tot, y = S, Sample = rownames(x))
    labels <- merge(labels, sdf, by = "Sample")
  }
  if (length(color) > 1) {
    data$color <- color
    names(data)[names(data) == "color"] <- deparse(substitute(color))
    color <- deparse(substitute(color))
  }
  if (length(label) > 1) {
    labels$label <- label
    names(labels)[names(labels) == "label"] <- deparse(substitute(label))
    label <- deparse(substitute(label))
  }
  p <- ggplot2::ggplot(data = data, ggplot2::aes_string(x = "Size", 
                                                        y = ".S", group = "Sample", color = color))
  p <- p + ggplot2::labs(x = "Sequence Sample Size", y = "Species Richness")
  if (!is.null(label)) {
    p <- p + ggplot2::geom_text(data = labels, ggplot2::aes_string(x = "x", 
                                                                   y = "y", label = label, color = color), size = size, 
                                hjust = 0)
  }
  p <- p + ggplot2::geom_line()
  if (se) {
    p <- p + ggplot2::geom_ribbon(ggplot2::aes_string(ymin = ".S - .se", 
                                                      ymax = ".S + .se", color = NULL, fill = color), alpha = 0.2)
  }
  if (plot) {
    plot(p)
  }
  invisible(p)
}

p= ggrare_2(Donor.count, label = "Concentration", color = "SampleName", parallel = T, size=7)+facet_grid(~PCR)

svg("rarefaction_curve_donor.svg", width = 15, height = 10)
p+theme_bw()+ylab("ASVs richness")+xlab("Reads")+ aes_string()+
  scale_color_manual(values= c("brown","black"), labels= c("HD1","HD2"), name= NULL) + scale_fill_manual(values = c("brown","black") ,guide=F)+ 
  scale_x_continuous(limits = c(0,50000))+ xlab("Reads")+  
  theme(axis.title = element_text(size = 25, face="bold"), axis.text = element_text(size = 20),
        strip.background = element_blank(), strip.text = element_text(size = 40, face="bold"), 
        legend.text = element_text(size = 25), legend.title = element_text(size = 25),panel.grid = element_blank())

dev.off()

"We know that we lose ASVs with dilutions, now let's see the percentage of ASVs that are still shared between samples"
"First let's compare the number of ASVs detected for each sample and the number of reads that are present for each samples"

ASVs= psmelt(Donor)#extract the object


#Then prepare a nice tidy df

shared_ASVs= as.data.frame(ASVs[,c("Abundance","SampleName","PCR","Concentration", "Phylum","Class","Order","Family","Genus","Species","ASV")])%>% #select required columns
    unite(col = "taxa", c("Phylum","Class","Order","Family","Genus","Species","ASV"), sep = "|") %>% #Create a single vector of taxa
        spread(key=taxa, value= Abundance) %>% #then spread
              unite(col= "Name", 1:3) %>% set_rownames(., .$Name)%>% select(-1)%>% t() %>% as_tibble() #Then prepare a nice tidy dataframe
#Make sure to remove character vector before transposing

Cross = crossprod(shared_ASVs>0) #Get a matrix with ASVs that are shared between samples
# Extract the wanted columns such as : Nested PCR for both Donors separately and for Standard PCR too
HD1_nested = as.data.frame(Cross[1:5,"HD1_Nested_10^8"])%>% rownames_to_column(.) %>% set_colnames(c("Sample","10^8"))
HD1_standard= as.data.frame(Cross[6:9,"HD1_Standard_10^8"])%>% rownames_to_column(.)%>% set_colnames(c("Sample","10^8"))
HD2_nested= as.data.frame(Cross[10:14, "HD2_Nested_10^8"])%>% rownames_to_column(.)%>% set_colnames(c("Sample","10^8"))
HD2_standard=as.data.frame(Cross[15:18,"HD2_Standard_10^8"])%>% rownames_to_column(.)%>%  set_colnames(c("Sample","10^8"))

Overlap <- rbind(HD1_nested, HD1_standard, HD2_nested, HD2_standard) %>% set_colnames(c("Sample","ASV_shared")) %>% set_rownames(.$Sample) # Bind the rows
Overlap= separate(Overlap, Sample, into = c("Sample","PCR","Concentration"), sep= "_") # Separate the sample vector to obtain three grouping vectors

# % ASV shared
ASV_tot <- data.frame(ASV_tot= apply(otu_table(Donor), 1,function(x)sum(x>0)))%>%  # Get the total number of ASVs
  set_rownames(with(sample_data(Donor), paste(SampleName, PCR, Concentration, sep="_")))
Overlap <- merge( Overlap, ASV_tot, by="row.names") # Merge the two dataframes

Overlap$Percentage<- (Overlap$ASV_shared/Overlap$ASV_tot)*100 #Percentage of ASV_shared compared to total ASVs for each samples

#Graphical representation
svg("Shared_ASV.svg", width = 15, height = 10)
ggplot(Overlap, aes(x=Concentration, fill=PCR))+
  geom_line(mapping = aes(x=factor(Concentration), y=Percentage*1.5, group=PCR, color=PCR), linetype="dashed" )+
  geom_point(mapping = aes(x=factor(Concentration), y=Percentage*1.5, group=PCR, color=PCR))+
  geom_bar(aes( y=ASV_shared), stat = 'identity', position = position_dodge(preserve = "single"))+
  labs(x="Microbes quantity", y="Shared ASV with the highest concentration")+ facet_grid(~Sample, scales = "free_x")+
  scale_y_continuous(sec.axis = sec_axis(~(./150), name = "Percentages", labels = scales::percent) )+ scale_x_discrete(labels= c("10^4"="10⁴","10^5"="10⁵","10^6"="10⁶","10^7"="10⁷","10^8"="10⁸"))+
  scale_fill_manual(values=c("black","brown"))+ scale_color_manual(values=c("black","brown"))+
  theme_bw()+theme(panel.grid.minor = element_blank(), axis.text.x = element_text(size = 30, face="bold"),
                   axis.text.y = element_text(size=15), axis.title.y = element_text(size = 30),
                   strip.text = element_text(size = 35, face="bold"), axis.title.x = element_text(size=30, face="bold"), 
                   legend.text = element_text(size = 20), legend.title = element_text(size = 20), strip.background = element_blank())
dev.off()


#Now that we found that percentage of ASV shared is dropping, we want to know which taxa are lost.
#Overlap samples by samples
reads= c(0,5)[1] # Select the number of reads per ASV for which you consider an ASV is a biologically "real" sequence, 
                # meaning not an artifact of sequencing and bioinformatic handling, the results is only slightly modified 
taxa_donor = as.data.frame(tax_table(Donor))
otu_donor= data.frame(otu_table(Donor, taxa_are_rows = F)) %>% 
  set_colnames(., with(taxa_donor, paste(Phylum, Class, Order, Family, Genus, Species, ASV, sep=" "))) # Aggregate phylogenetic information and the count table
otu_donor1= cbind(sample_data(Donor), otu_donor)#construct the dataset
overlap_samples= as(otu_donor1[,c( "PCR", "Concentration","SampleName")], "data.frame")
overlap_samples$name= paste(overlap_samples$SampleName,overlap_samples$PCR,overlap_samples$Concentration , sep="_")
logical= apply(otu_donor1[,10:470],c(1,2), function(x){ifelse(x>reads, 1,0)}) #Logical if ASV is present or not in the sample
overlap_samples = merge(overlap_samples, logical,by = 'row.names' ) #Merge logical otu_table and metadata

#Create the loop

{
  "first, make the lists : - for the donor 
                           - for the PCR 
                           - the concentrations (2 lists)
                           - the phylogenic levels"
  donorlist = c("HD1","HD2")
  concentration1list=c("10^4","10^5","10^6","10^7","10^8")
  concentration2list= c("10^8")
  pcrlist=c("Nested","Standard")
  phylolist= c("Phylum","Class","Family")
  bis2 = NULL
  bis3= NULL
  tmp= NULL
  names(bis)
  for(pcr in pcrlist){ #Make the loop for both PCR protocols
  for (donor in donorlist) {#both donor
    
    for(concentration1 in concentration1list){ # Each concentration
      if(concentration1=="10^4" & pcr=="Standard"){ # Standard PCR didn't give an amplicon for this dilution, 
                                                    # so we force the loop to jump this dilution
        
       cat( concentration1, "doesn't exist in", pcr, "\n")} #Just to be sure loop is doing what it should do
           else {
      
      for(concentration2 in concentration2list){
        cat("processing", concentration1, concentration2, "\n")
             
        if(concentration1 != concentration2){ #We don't want the loop to work on 10^8 versus 10^8
          bis = filter(overlap_samples, Concentration==concentration1 | Concentration==concentration2)%>%
            filter(., SampleName==donor & PCR==pcr) %>% select(5:466)
          row.names(bis)<- bis$name #Change row.names
          bis= as(bis[,-1], "data.frame")%>% t() #Remove old names
       
          shared <- as_vector(apply(bis, 1, sum)) # Create a logical column with 2 if the ASV is shared by both samples, 1 by only one and 0 if no overlap
          bis= cbind(bis, shared) # Bind the two 
          
          colnames(bis)[colnames(bis)=="shared"]<- paste(donor, pcr,concentration1, concentration2, sep = "_") #Set the new column name 
          bis=as.data.frame(bis)
          # Create the final df
          bis3 = cbind( bis3, bis[,3])%>% as.tibble() #Add a column for each loop
          colnames(bis3)[ncol(bis3)] <-colnames(bis)[3]
          rownames(bis3)= rownames(bis)
          print(colnames(bis)[3])       
          
              } 
        else {cat("dodging",concentration1, "versus",concentration2, "\n")
            }
      
      bis2 = bis3 %>% rownames_to_column("taxa") %>% separate(col = taxa, into=c("Phylum","Class","Order","Family","Genus","Species","ASV","number"), 
                                                              sep = " ", remove = T)
      bis2= subset(bis2$Phylum!="NA", x = bis2) #Remove unaffiliated phyla
      bis2= as(gather(bis2, key="Overlap", value="value", -Phylum, -Class, -Order,-Family, -Genus, -Species, -ASV, -number), "data.frame") # Choose long format
      bis2= separate(data= bis2, col= "Overlap", into = c("Donor","PCR","Concentration1","Concentration2"), sep = "_" )
      bis2$Overlap= paste(bis2$Donor, bis2$Concentration1, bis2$Concentration2, sep="|")
      shared_both=subset(bis2, bis2$value==2)
      not_shared= subset(bis2, bis2$value==1)
      not_present= subset(bis2, bis2$value==0)
       }   
      }
     }
  shared_all= shared_both
  shared_all= rbind(shared_all, shared_both)%>% as.data.frame() # Bind for each iteration
  shared_both=NULL
   }
  }
  for (phylo in phylolist) { # For each phylogenetic level
    cols<-length( unique(shared_all[,phylo]))
    shared_Standard= subset(shared_all,PCR=="Standard")
    shared_Nested= subset(shared_all,PCR=="Nested")
    p= ggplot(shared_all, aes(x=Concentration1, fill=shared_all[,phylo]))+
      geom_bar(stat="count", position='fill')+facet_grid(Donor~PCR, scales = "free", space = "free")+theme_bw()+scale_x_discrete(labels= c("10^4"="10⁴","10^5"="10⁵","10^6"="10⁶","10^7"="10⁷","10^8"="10⁸"))+
      ggtitle(phylo)+ labs(x="Microbes quantity", y= "Relative abundance")+
      theme(axis.title.y = element_text(size= 30 , face="bold"), axis.text = element_text(size=30), 
                           strip.background = element_blank(), strip.text = element_text(size=35, face="bold"),
                           axis.title.x = element_text(size=30, face="bold"), 
                           panel.grid = element_blank(), legend.text = element_text(size = 30, face="bold.italic"), legend.title = element_blank(),
                           plot.title = element_text(size = 40, face="bold", hjust = 0.5),
                           axis.text.x =   element_text(size = 35, face="bold") )+
      scale_y_continuous(labels = scales::percent)+ 
      scale_fill_manual(values= colorRampPalette(brewer.pal(12, "Paired"))(cols), na.value="black")+guides(fill = guide_legend(ncol = 1))
    
    
    svg(filename = paste(phylo,reads, "overlap.svg"), width = 20, height=15)
    print(p)
     dev.off()
  }
  "clear the memory"
  shared_both=NULL
  not_shared=NULL
  not_present=NULL
  shared_all=NULL
}

## MCS extraction
#In order to compare to the theoretical composition, we will subset taxas and merge ASVs to the genus level. 

# Standard extraction
      #Alpha_diversity
"Prepare object for later"
MCS= subset_samples(ps, Platform=="BioFidal" & SampleOrigin!="NegCTRL") %>%
  subset_taxa(., Genus=="Bacillus"| Genus=="Enterococcus"| 
                Genus=="Escherichia/Shigella"|Genus=="Lactobacillus"|Genus=="Listeria"|Genus=="Pseudomonas"|
                Genus=="Salmonella"|Genus=="Staphylococcus")%>% transform_sample_counts(., function(x)x/sum(x))

MCS.count= subset_samples(ps, Platform=="BioFidal")#Get MCS as read counts
ranacapa::ggrare(MCS.count, label = "SampleName", color = "Protocol")+facet_grid(~PCR) #See the rarefaction curve
"No difference appears here"

p= plot_bar(MCS, x= "Sample", fill = "ASV")+facet_grid(PCR~Genus)+theme_bw() #See the distribution of ASV within the genus expected
p+theme(axis.text.x = element_text(angle = 90, hjust = 0.5, vjust = 0.5)) #Plot

MCS_whole_cell<- subset_samples(MCS, SampleOrigin=="MCS Whole Cell") #Without genomic standards

MCS_alpha= subset_taxa(MCS_whole_cell, Genus=="Bacillus"| Genus=="Enterococcus"| 
                         Genus=="Escherichia.Shigella"|Genus=="Lactobacillus"|Genus=="Listeria"|Genus=="Pseudomonas"|
                         Genus=="Salmonella"|Genus=="Staphylococcus")%>% tax_glom(., "Genus")%>%
  estimate_richness(., measures = "Shannon")%>%cbind(sample_data(MCS_whole_cell,.)) #Get the alpha-diversity

#Determine the theoretical alpha-diversity
shannon <- function(x){
  x <- x[!is.na(x)]
  result <- 0
  nval <- length(x)
  sumval <- sum(x)
  if (sumval != 0) {
    for (i in 1:nval) { 
      if (x[i] != 0) {
        result <- result + x[i]*log(x[i])
      }
    }
    result <- (log(sumval)-(1/sumval)*result)
  } else {
    return <- -1 #Error value
  }
  return(result)
}

x= matrix(c(0.174,	0.099,	0.101,	0.184,	0.141,	0.042,	0.104,	0.155)) # Theoretical abundance from manufacturer
apply(x, 2, shannon)  # Apply the shannon function to determine the Shannon index for the theoretical abundance

#By sample
svg("shannon_MCS.svg", width = 15, height = 10)
ggplot(MCS_alpha, aes(x=SampleName, y=Shannon, fill=Protocol))+geom_bar(stat="identity")+
  facet_grid(~PCR, space = "free", scales = "free_x")+
  geom_hline(yintercept = 2.009983 , linetype="dashed", size=2)+
  scale_fill_manual(values = c("ivory4","sienna3",'goldenrod'))+theme_bw()+ 
  scale_x_discrete(labels= c("Chemical","MB1","MB2","MB3","MP1","MP2","MP3"))+
  ylab("Shannon alpha-diversity")+
  theme(legend.position = "none", strip.background = element_blank(),
    axis.text.x = element_text(size=25, face = "bold", angle = 30, vjust = 0.5), 
     axis.text.y = element_text(size = 15, face = "bold"),
      axis.title.x = element_blank(), axis.title.y = element_text(size=25, face="bold"),
         strip.text = element_text(size = 35, face = "bold"),panel.grid = element_blank())

dev.off()

"Let's findout if the differences are statistically different"
wilcox.test(MCS_alpha$Shannon~MCS_alpha$PCR, paired=T)
"Significant"

kruskal.test(MCS_alpha$Shannon~MCS_alpha$Mechanical_Lyse) #Change to Mechanical_lyse or Protocol
"Not significant"

#Plot relative abundance

"We need  to manually add theoretical values"
MCS_all= subset_samples(ps, Platform=="BioFidal" & SampleOrigin!="NegCTRL") %>%
  subset_taxa(., Genus=="Bacillus"| Genus=="Enterococcus"| 
                Genus=="Escherichia/Shigella"|Genus=="Lactobacillus"|Genus=="Listeria"|Genus=="Pseudomonas"|
                Genus=="Salmonella"|Genus=="Staphylococcus")%>% transform_sample_counts(., function(x)x/sum(x)) %>% tax_glom(., "Genus")%>% psmelt(.)

MCS_all=as.data.frame(MCS_all[,c("Abundance","SampleOrigin","SampleName","PCR", "Protocol","Mechanical_Lyse","Genus")])%>% 
  spread(., key=Genus, value=Abundance) # Get the wide dataframe
Theory= c("Theory","Theory","Theory", "Theory", "Theory",	0.174,	0.099,	0.101,	0.184,	0.141,	0.042,	0.104,	0.155) # Add theoretical abundance
MCS_all= data.frame(rbind(MCS_all, Theory)) #Bind the two datasets

MCS_all= gather(MCS_all, key="Bacteria","Abundance", -PCR,-Protocol, -Mechanical_Lyse, -SampleName, -SampleOrigin) # Now get the long version to plot
MCS_all$Abundance= as.numeric(MCS_all$Abundance) # Make sure abundance is Numeric

"Ok dataset is ready now"
#Subset whole_cell samples and DNA samples
Whole_cell<- subset(MCS_all, Protocol!="DNA")

Whole_cell$PCR= factor(Whole_cell$PCR,levels=c("Nested","Theory","Standard")) #Order PCR as factor
#Plot
svg("RA_MCS.svg", width=20, height = 15)
ggplot(Whole_cell, aes(x=SampleName, y=Abundance, fill=Bacteria))+
  geom_bar(stat = "identity", position = "fill")+ ylab("Relative abundance")+
  theme_bw()+theme(axis.title.x = element_blank(), axis.text.x = element_text(size=25, 
  face="bold", angle = 30, vjust = 0.5), axis.text.y = element_text(size = 15),
  strip.background = element_blank(), axis.title.y = element_text(size = 25, face = "bold"),
  strip.text = element_text(size = 30, face = "bold"), axis.ticks.x = element_blank(),
  panel.grid = element_blank(), legend.text = element_text(size=15, face = "bold.italic"), 
  legend.title = element_blank())+
  facet_grid(~PCR, scales = "free", space = "free")+
  scale_fill_futurama("planetexpress")
dev.off()

# Let's analyze beta_diversity
Whole_cell= spread(Whole_cell, key=Bacteria, value= Abundance) # Wide dataframe
MCS_beta=  vegdist(Whole_cell[,6:13], "bray") %>% dudi.pco(., scannf = F, nf=5) #Get distance and the PCoA
group_MCS= factor(Whole_cell$PCR) #Create the group for plotting and stats

svg(filename="PCoA_MCS.svg", 
    width=8, 
    height=6, 
    pointsize=12)
shape= c(19,18,17) #Set shapes
shape= shape[as.factor(Whole_cell$PCR)] #Give the vector for the shapes
s.class(MCS_beta$li, fac=group_MCS, col =  c("black","black","brown"), clabel = 0, cpoint = 2.5, grid = F, origin = c(0,0), cstar = ,
        axesell = T, pch=shape) #Looks like there is two nice clusters   #Change clabel to have the name of the ellipse
x= betadisper(vegdist(Whole_cell[,6:13], "bray"), group = Whole_cell$PCR)
x$eig/sum(x$eig) # Get the axis participation
dev.off()

"Try with other variables"
s.class(MCS_beta$li, fac= factor(Whole_cell$Protocol)) #We have no clusters based on protocols
s.class(MCS_beta$li, fac= factor(Whole_cell$Mechanical_Lyse),
        col = c("black","red","green")) #There might be clusters here

#Calculate PERMANOVA value for PCR clusters
"Just remove Theory vector as we don't want it to interfere in the stats"
adonis(vegdist(Whole_cell[-15,6:13], "bray")~PCR, data = data.frame(Whole_cell[-15,]),permutations = 10000, method = "bray" )
"significant"

adonis(vegdist(Whole_cell[-15,6:13], "bray")~Mechanical_Lyse, data = data.frame(Whole_cell[-15,]),permutations = 10000, method = "bray" )
"significant"


"Plot the distance for each sample to the theoretical abundance"
row.names(Whole_cell)<- paste(Whole_cell$SampleName, Whole_cell$PCR)
brayvegan<- vegan::vegdist(Whole_cell[,6:13], method = "bray") %>% as.matrix()

brayvegan<- as.data.frame(brayvegan[,"Theory Theory"]) #Keep only the column that explain the distance to theoretical abundance
brayvegan<- merge(brayvegan, Whole_cell[,1:5], by="row.names")%>%
  set_colnames(., value=c("Name","Bray","SampleOrigin","SampleName","PCR","Protocol", "Mechanical_Lyse"))%>%
  filter(., SampleName!="Theory") #Change colnames and remove the "Theory"
brayvegan$Mechanical_Lyse= factor(brayvegan$Mechanical_Lyse, levels=c("3x30","2x5","4x5")) #Order

#Plot
ggplot(brayvegan, aes(x=SampleName, Bray))+geom_bar(stat="identity")+ facet_grid(~PCR, space = "free", scales = "free_x")+
ylab("Bray-Curtis Distance")+theme_bw()+
  theme(strip.text = element_text(size = 40, face = "bold"), strip.background = element_blank(), legend.position = "none", 
        legend.text = element_text(size = 25, face="bold"), axis.title.x = element_blank(), axis.text.x = element_text(size = 30, face = "bold"),
        legend.title = element_text(size = 20, face="bold"), axis.title.y=element_text(size = 30, face="bold"), 
        axis.text.y = element_text(size = 25), panel.grid = element_blank())

wilcox.test(brayvegan$Bray~brayvegan$PCR, paired=T)
"The plot in the paper was modified afterward with inkscape to bind the Bray distance plot with the abundance plot"

MCS_genomic= subset(MCS_all, Protocol=="DNA"| Protocol=="Theory") #Get only the genomic samples

svg("MCS_genomic.svg", width = 20, height = 15) 
MCS_genomic$PCR= factor(MCS_genomic$PCR, levels= c("Nested","Theory","Standard"))
ggplot(MCS_genomic, aes(x=SampleName, y=Abundance, fill=Bacteria))+
  geom_bar(stat = "identity", position = "fill")+ ylab("Relative abundance")+
  theme_bw()+theme(axis.title.x = element_blank(), axis.text.x = element_blank(), axis.text.y = element_text(size = 15),
                   strip.background = element_blank(), axis.title.y = element_text(size = 25, face = "bold"),
                   strip.text = element_text(size = 30, face = "bold"), axis.ticks.x = element_blank(),
                   panel.grid = element_blank(), legend.text = element_text(size=25, face = "bold.italic"), 
                   legend.title = element_blank())+
  facet_grid(~PCR, scales = "free", space = "free")+
  scale_fill_futurama("planetexpress")

dev.off()

"Now let's see if the DNA samples are close to the theory or the Whole Cell samples"
MCS_all= spread(MCS_all, key=Bacteria, value=Abundance)
row.names(MCS_all)<- MCS_all$Sample

PCoA_final = vegdist(data.frame(MCS_all[,6:13]), method = "bray")%>% dudi.pco(., scannf = F,  nf=5)
x= betadisper(vegdist(data.frame(MCS_all[,6:13]), method = "bray"), group = MCS_all$PCR)#get eigenvalues
(x$eig/sum(x$eig))*100 #Get axis contribution to PCoA

"Plot PCoA with two different segregations: Standard origin (aka Whole_cell or Genomic) and
Mechanical_Lyse protocols"
shapes= c(19,17,15) #Set shapes
shapes= shapes[as.factor(MCS_all$PCR)] #Give the vector for the shapes
colors= c("brown","black","cyan4")#colors
colors= colors[as.numeric(MCS_all$Standard)] #Vector for colors
#Plot
svg("PCoA_all_Standard.svg", width = 15, height = 10)
par(lwd=3.5)
s.class(PCoA_final$li, fac = as.factor(MCS_all$SampleOrigin), pch=shapes,
              col = c("brown","black","cyan4"),
              cpoint = 4, grid = F, cstar = 1, clabel = 0, origin = c(-0.1,0.1), addaxes = T, axesell = T)
dev.off()


svg("PCoA_all_Lyse.svg", width = 15, height = 10)
shapes2= c(1,15,17, 19,18)
shapes2= shapes2[as.factor(MCS_all$Protocol)]
par(lwd=3.5)
s.class(PCoA_final$li*-1, fac = as.factor(MCS_all$Mechanical_Lyse), 
              col = c("darkblue","deepskyblue","chartreuse4","brown","black"), pch= shapes2,
              cpoint = 4, grid = F,cstar = 1, clabel = 0, origin = c(-0.1,0.1), addaxes = T, axesell = T, include.origin = T) #Multiply by -1 to get the same orientation as the PCoA for whole-cell

dev.off()

"Get the PERMANOVA value for the whole_cell vs DNA standards"
adonis_dist2= vegdist(as.matrix(MCS_all[1:18,6:13]), method = "bray") #Remove theory as we want to know if whole_cell and genomic are different
plot(betadisper(adonis_dist2, group = factor(MCS_all[1:18,]$SampleOrigin))) #Just to check that the theory is out

adonis(formula = adonis_dist2~SampleOrigin, data = as.data.frame(MCS_all[1:18,]), permutations = 10000)
"As we expected they are different"
"Does PCR give a signif PERMANOVA ?"

adonis(formula = adonis_dist2~PCR, data = as.data.frame(MCS_all[1:18,]), permutations = 10000)
"Not significant"

##########################################
"try now to find which taxa are the more impacted by factors"
vec= MCS_all[19,6:13] #Get Theoretical abundance as a vector
x= cbind(MCS_all[,1:5], as.data.frame (log2(mapply("/", MCS_all[,6:13], vec)))) #Divide all rows by the vector we created

x$SampleName= gsub(x$SampleName, pattern = "MCS*", replacement = "DNA")
"We got a matrix of 19x13"
x_standard= subset(x, x$PCR=="Standard") #Subset by PCR
row.names(x_standard)<- x_standard$SampleName

x_nested= subset(x, x$PCR=='Nested') #Same
row.names(x_nested)= x_nested$SampleName

col_fun = circlize::colorRamp2(c(3,0,-4), c("steelblue3","white","black")) #Force the color-key to be the same for both heatmaps
Gram= c("black", "black", "red","black","black","red","red","black") #Prepare a vector for coloring by gram status
h1= Heatmap(as.matrix(t(x_standard[,6:13])), show_row_dend = F, show_column_dend = F, col = col_fun, show_heatmap_legend = F,
            cluster_columns = F, column_title = "Standard PCR",row_names_gp = gpar(col=Gram, fontface="bold.italic" ),
            column_title_gp = gpar(fontsize=40, fontface="bold"), column_names_gp = gpar(fontsize=25),
            column_order = c("Chemical","MB1","MB2","MB3", "MP1","MP2","MP3","DNA*1","DNA*2"))
h2= Heatmap(as.matrix(t(x_nested[,6:13])), show_row_dend = F, show_column_dend = F, col = col_fun, name = "Variation", 
            cluster_columns = F, column_title = "Nested PCR",row_names_gp = gpar(col=Gram, fontsize=25, fontface="bold.italic" ),
            column_title_gp = gpar(fontsize=40, fontface="bold"), column_names_gp = gpar(fontsize=25), 
            heatmap_legend_param = list(legend_height=unit(7,"cm"), legend_width=unit(10,"cm"), 
                                        legend_direction="horizontal", legend_position='bottom'), 
            column_order = c("Chemical","MB1","MB2","MB3", "MP1","MP2","MP3","DNA*1","DNA*2"))

svg("heatmap_variation_MCS.svg", width = 20, height=12)
draw(h1+h2, heatmap_legend_side="bottom")
dev.off()

"is Nested statistically better ?"
xsquare= as.data.frame(cbind(x[,1:6], x[,6:13]^2)) 
xsquare= subset(xsquare, Protocol!="DNA") #Subset either with DNA or whole_cell samples
bar= gather(xsquare[-15,], key="Bacteria","value",-SampleName, -PCR,-Protocol,-Mechanical_Lyse,-SampleOrigin)
t.test(data=bar, as.numeric(value)~as.factor(PCR), paired=T)


# Verify the chimera generation for each PCR protocols, a 2 step PCR is supposed to create more chimeras than a 1 step
# Use the file: dada2_filt_stats.txt
chimera= read.delim("dada2_filt_stats.txt")
chimera = rownames_to_column(chimera)
metadata2 = metadata
metadata2$alias= str_split(metadata$Filename, pattern="_", simplify = T)[,1] # Extract the pattern to make the names match
chimera2 = merge(metadata2, chimera, by.x="alias", by.y="rowname")  # Merge metadata and the values

tmp = chimera2[,c("PCR","Protocol", "tabled", "nonchim")] # Select the values needed
tmp$chimera= tmp$tabled-tmp$nonchim # Chimeras are defined here by the reads removed during the dada2 step:"removeBimeraDenovo"
tmp = pivot_longer(tmp, cols = c("chimera","nonchim"), names_to = "reads" )
#Plot
svg("end reads analysis.svg", width=10, height = 8)
ggplot(tmp)+geom_violin(aes(x= reads, y= value, fill=PCR), position = "dodge", alpha=0.3, trim=F)+
  geom_dotplot(aes(x= reads, y= value, fill=PCR ), binaxis = "y", stackdir = "center", position = "dodge", dotsize = .5)+
  scale_fill_discrete(labels=c("Nested PCR","Standard PCR"))+
  scale_x_discrete(labels=c("Pre","Post"))+labs(y="Reads count")+scale_fill_manual(values=c("brown","orange"))+
  theme_bw()+
  theme(text = element_text(size=30), legend.position = "bottom", axis.title.x = element_blank(), axis.text.x = element_text(size=30, face="bold"))
dev.off()

wilcox.test(chimera_dna$tabled-chimera_dna$nonchim~chimera_dna$PCR) # Get the stats
wilcox.test(chimera_dna$tabled~chimera_dna$PCR) # Get the stats
"We can see that there is more chimeras with the Nested PCR (2 step PCR) but they are nicely handled by dada2 as we don't see
a statistical difference between the two protocols"

# Observed ASVs
"We do not have a difference in read count but is there more ASVs in the Nested ?"
svg("observed asvs.svg", width=12, height=7)
MCS%>% subset_samples(., SampleOrigin != "NegCTRL")%>% plot_richness(., measures = "Observed", x="PCR", color="PCR")+geom_boxplot(aes(fill=PCR), alpha=0.3)+ylab("Observed ASVs")+scale_fill_manual(values=c("brown","orange"))+
  scale_color_manual(values=c("brown","orange"))+
  stat_compare_means(method="wilcox.test", label.x.npc = "middle", size=5)+theme_bw()+theme(text = element_text(size=25), axis.title.x = element_blank(), strip.background = element_blank(),
                                                                                            legend.position = "none")
dev.off()

# Unexpected ASVs
"Sanity check, we look for bacteria we don't expect in the results
This standard is composed of 8 bacteria, we will remove the Genus expected and plot the unexpected genus"
#Remove the expected genus
false= subset_samples(ps.RA, Platform=="GenoToul" & SampleOrigin!="NegCTRL")%>% 
  subset_taxa(., Genus!="Bacillus")%>%subset_taxa(., Genus!="Enterococcus")%>%
  subset_taxa(., Genus!="Escherichia/Shigella")%>% subset_taxa(., Genus!="Lactobacillus")%>%
  subset_taxa(., Genus!="Listeria")%>% subset_taxa(., Genus!="Pseudomonas")%>% subset_taxa(., Genus!="Salmonella")%>%
  subset_taxa(., Genus!="Staphylococcus")%>% prune_taxa(taxa_sums(.)>0, .)%>%
  psmelt(.)
svg("false abundance MCS.svg", width = 17, height = 7)
ggplot(false, aes(x=SampleName, y=Abundance, fill=Genus))+geom_bar(stat = "identity", position = "stack")+
  facet_grid(~PCR)+scale_y_continuous(labels=scales::percent)+scale_x_discrete(labels=c("Chemical", "MB1","MB2","MB3","DNA1","DNA2", "MP1","MP2","MP3"))+scale_fill_lancet()+
  theme_bw()+theme(axis.title.x = element_blank(),panel.grid = element_blank(), text=element_text(size=20, face="bold"), legend.text = element_text(face = "bold.italic"), 
                   strip.text = element_text(size=25), strip.background = element_blank(), legend.position = "bottom")

dev.off()
